/*
 * This file is part of the KFTPGrabber project
 *
 * Copyright (C) 2003-2004 by the KFTPGrabber developers
 * Copyright (C) 2003-2004 Jernej Kos <kostko@jweb-network.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
 * NON-INFRINGEMENT.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA.
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */

#ifndef KFTPBOOKMARKS_H
#define KFTPBOOKMARKS_H

#include <qstring.h>
#include <qdom.h>
#include <qvaluelist.h>

#include <kpopupmenu.h>
#include <kaction.h>
#include <kurl.h>

class KFTPClientThr;
class KFTPBookmarksShare;

/**
Provides easy FTP server bookmarks manipulation.

@author Jernej Kos
*/
class KFTPBookmarks : public QObject {
Q_OBJECT
public:
    KFTPBookmarks();
    KFTPBookmarks(const KFTPBookmarks &b);

    // DOM functions
    void domReadFile(const QString &fileName);
    void domSaveFile();
    QDomDocument getXMLDocument() { return xmlDoc; }

    // DOM server functions
    QDomNode domFindServerByName(const QString &serverName);
    QDomNode domFindServerByHost(const QString &serverHost);
    QDomNode domFindServerByUrl(const KURL url, QDomNode parent);
    QDomNode domFindNodeByXMLPath(const QString &path);
    void domDeleteServer(QDomNode server);
    
    bool domServerExistsByUrl(const KURL url);
    bool domServerExistsByName(const QString &serverName);
    bool domServerExistsByHost(const QString &serverHost);

    // DOM category functions
    QDomNode domFindCategoryByName(const QString &categoryName);
    bool domCategoryExistsByName(const QString &categoryName);
    void domDeleteCategory(QDomNode category);
    void domRenameCategory(QDomNode category, const QString &newName);
    void domCreateCategory(QDomNode parent, const QString &categoryName);

    // DOM general functions
    void domAddProperty(QDomElement element, const QString &name, const QString &text);
    bool domDeleteProperty(QDomElement element, const QString &name);
    void domSetProperty(QDomElement element, const QString &name, const QString &text);
    QString domGetProperty(QDomNode node, const QString &name);
    void domAddOption(QDomElement element, const QString &name, const QString &value);
    void domAddOption(QDomElement element, const QString &name, int value);
    bool domDeleteOption(QDomElement element, const QString &name);
    void domSetOption(QDomElement element, const QString &name, const QString &value);
    void domSetOption(QDomElement element, const QString &name, int value);
    QString domGetOption(QDomNode node, const QString &name);

    // GUI functions
    KActionMenu *getSendToMenu();
    void populateZeroconfMenu(KActionMenu *parentMenu);
    void populateBookmarksMenu(KActionMenu *parentMenu, QDomNode parentNode, bool base = false, QObject *data = 0L);

    // URL related functions
    KURL urlFromClientSocket(KFTPClientThr *client, const QString &path = 0);
    KURL urlFromServer(QDomNode server);
    void setFTPOptions(QDomNode server, KFTPClientThr *client);
    void setFTPOptions(const KURL &url, KFTPClientThr *client);
    
    void doEmitUpdate();
    
    void setBookmarks(KFTPBookmarks *b);
private:
    QString m_xmlFile;
    QDomDocument xmlDoc;
    KFTPBookmarksShare *m_bookmarksShare;

    QDomNode domFindTagByName(const QString &tag, const QString &name);
signals:
    void update();
private slots:
    void slotBookmarkExecuted();
    void slotZeroconfExecuted();
};

extern KFTPBookmarks *FTPBookmarks;

#endif
