/*
 * This file is part of the KFTPGrabber project
 *
 * Copyright (C) 2003-2004 by the KFTPGrabber developers
 * Copyright (C) 2003-2004 Jernej Kos <kostko@jweb-network.net>
 * Copyright (C) 2004 Markus Brueffer <markus@brueffer.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
 * NON-INFRINGEMENT.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA.
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */

#ifndef _KFTPGRABBER_H_
#define _KFTPGRABBER_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <kmdimainfrm.h>

#include "kftpclientthread.h"
#include "kftpmainactions.h"

class KFTPSystemTray;
class KFTPFileDirView;
class KFTPBookmarkSidebar;
class KFTPBookmarkEditorListView;
class KFTPZeroConfListView;

/**
 * @short Application Main Window
 * @author Jernej Kos <kostko@jweb-network.net>
 */
class KFTPGrabber : public KMdiMainFrm
{
    Q_OBJECT
public:
    /**
     * Default Constructor
     */
    KFTPGrabber();

    /**
     * Default Destructor
     */
    virtual ~KFTPGrabber();

    /**
     * This method creates the statusbar 
     */
    void initStatusBar();

    /**
     * This method creates all other widgets (like KListView) that
     * are needed in the application.
     */
    void initMainView();

    /**
     * This method adds a toolwindow (sidebar)
     * Note: the widget must have a unique name within the scope of all toolwindows
     */
    KMdiToolViewAccessor *addToolView(KDockWidget::DockPosition position, QWidget *widget, const QPixmap &icon, const QString &sname, const QString &tabToolTip = 0, const QString &tabCaption = 0);

    /**
     * This method removes a toolwindow (sidebar)
     * Note: the widget gets deleted
     */
    bool removeToolView(QWidget *);
    
    /**
     * This method removes a toolwindow (sidebar)
     */
    bool removeToolView(KMdiToolViewAccessor *);

protected:
    bool queryClose();
private:
    KFTPMainActions *m_actions;

    KActionMenu *m_bookmarkMenu;
    KActionMenu *m_zeroconfMenu;
    
    KFTPBookmarkSidebar *m_bookmarkSidebar;
    KFTPZeroConfListView *m_zeroconfSidebar;
public slots:
    void initBookmarkMenu();
    void slotQuickConnect(QString title=QString(), QString host=QString(), int port=21);
private slots:
    void appShutdown();
    void showBookmarkEditor();
    void slotUpdateStatusBar();
    void slotReadBookmarks();
signals:
    void qsaAppStartup();
    void qsaAppExit();
};

#endif // _KFTPGRABBER_H_
