/*
 * This file is part of the KFTPGrabber project
 *
 * Copyright (C) 2003-2004 by the KFTPGrabber developers
 * Copyright (C) 2003-2004 Jernej Kos <kostko@jweb-network.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
 * NON-INFRINGEMENT.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA.
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */

#ifndef KFTPQUEUE_H
#define KFTPQUEUE_H

#include <qstring.h>
#include <qvaluelist.h>
#include <qtimer.h>

#include <kurl.h>
#include <kurldrag.h>

#include "kftpclientthread.h"
#include "kftpqueueprocessor.h"
#include "kftpqueueconverter.h"
#include "misc.h"

#include "kftptransfer.h"
#include "kftptransferfile.h"
#include "kftptransferdir.h"

namespace KFTPNetwork {
  class Socket;
}

using namespace KFTPGrabberBase;

class KFTPSession;

typedef QPtrList<KFTPQueue::Transfer> KFTPQueueTransfers;

class KFTPQueueManager : public QObject {
Q_OBJECT
friend class KFTPSession;
friend class KFTPQueueConverter;
friend class KFTPNetwork::Socket;
public:
    KFTPQueueManager(QObject *parent);

    void insertTransfer(KURLDrag *drag);
    void insertTransfer(KFTPQueue::Transfer *transfer);
    void removeTransfer(KFTPQueue::Transfer *transfer);
    void removeTransfer(long id);
    void clearQueue();

    KFTPQueue::Transfer *findTransfer(const QString &sourcePath = 0);
    KFTPQueue::Transfer *findTransfer(long id);

    void moveTransferUp(long id);
    void moveTransferDown(long id);
    bool canBeMovedUp(long id);
    bool canBeMovedDown(long id);

    KFTPQueueTransfers *getQueueTransferList();
    KFTPQueueConverter *getConverter() { return m_converter; }

    void setEmitUpdate(bool value);
    void doEmitUpdate();

    filesize_t getDownloadSpeed();
    filesize_t getUploadSpeed();
    int getTransferPercentage();
    int getNumRunning();
    
    // Methods for transfering all files in the queue, one by one
    void sortTransfersByServer();
    void startQueueTransfer();
    void abortQueueTransfer();
    bool queueProcRunning() { return m_queueProc->isRunning(); }

    KFTPQueue::Transfer *spawnTransfer(KURL srcURL, KURL dstURL, filesize_t size, bool dir, KFTPQueue::TransferType t_type, 
                                       bool ignoreSkip = false, bool insertToQueue = true, QObject *parent = 0L, bool noScan = false);
private:
    KFTPQueueTransfers p_queueTransfers;
    KFTPQueueProcessor *m_queueProc;
    KFTPQueueConverter *m_converter;
    int p_lastQID;
    bool p_emitUpdate;

    filesize_t m_curDownSpeed;
    filesize_t m_curUpSpeed;
private slots:
    void slotTransferComplete(long);
    void slotTransferStart(long);
    void slotTransferAbort(long);
    
    void slotQueueProcessingComplete();
signals:
    void newTransfer(KFTPQueue::Transfer*);
    void transferRemoved(long);
    void queueUpdate();
    
    void qsaTransferComplete(long);
    void qsaTransferStart(long);
    void qsaTransferAbort(long);
};

extern KFTPQueueManager *FTPQueueManager;

#endif
