/*
 * This file is part of the KFTPGrabber project
 *
 * Copyright (C) 2004 by the KFTPGrabber developers
 * Copyright (C) 2004 Jernej Kos <kostko@jweb-network.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
 * NON-INFRINGEMENT.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA.
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */

#ifndef KFTPGRABBERBASEKFTPHOWLTHREAD_H
#define KFTPGRABBERBASEKFTPHOWLTHREAD_H

// FIXME Howl headers are crappy.
#undef PACKAGE
#undef VERSION
#define SW_ENDIAN 1

#include <howl.h>
#include <qobject.h>
#include <qthread.h>
#include <qvaluelist.h>
#include <qevent.h>

// Define the event ID
#define HOWL_EVENT_ID 65200

/**
This class actually does nothing ;) It is just used for forwarding events outside
the thread to the GUI thread, so the app won't crash.
*/
class HowlEvent : public QCustomEvent
{
public:
    HowlEvent()
      : QCustomEvent((QEvent::Type) HOWL_EVENT_ID, 0L) {}
};

class KFTPHowlService
{
friend class KFTPHowlThread;
public:
    KFTPHowlService() {}
    KFTPHowlService(const QString &name, const QString &ip, int port)
    {
      m_serviceName = name;
      m_serviceIp = ip;
      m_servicePort = port;
    }
    
    QString getServiceName() { return m_serviceName; }
    QString getServiceIp() { return m_serviceIp; }
    int getServicePort() { return m_servicePort; }
private:
    QString m_serviceName;
    QString m_serviceIp;
    int m_servicePort;
};

/**
This class provides Howl integration into Qt event loop. It is used to forward events to callback functions.

@author Jernej Kos
*/
class KFTPHowlThread : public QObject, public QThread
{
Q_OBJECT
public:
    KFTPHowlThread();
    
    bool isHowlEnabled();
    QValueList<KFTPHowlService> getServiceList() { return m_services; }
    
    virtual void run();
private:
    sw_discovery m_howlDiscovery;
    sw_result m_howlResult;
    sw_discovery_browse_id m_howlId;
    sw_salt m_howlSalt;
    QValueList<KFTPHowlService> m_services;
    
    bool m_howlEnabled;
    
    static sw_result HOWL_API howlBrowser (
        sw_discovery discovery,
        sw_discovery_oid oid,
        sw_discovery_browse_status status,
        sw_uint32 interface_index,
        sw_const_string name,
        sw_const_string type,
        sw_const_string domain,
        sw_opaque extra);

    static sw_result HOWL_API howlResolver (
        sw_discovery discovery,
        sw_discovery_oid oid,
        sw_uint32 interface_index,
        sw_const_string name,
        sw_const_string type,
        sw_const_string domain,
        sw_ipv4_address address,
        sw_port port,
        sw_octets text_record,
        sw_ulong text_record_len,
        sw_opaque extra);
signals:
    void _howlListUpdate();
};

class KFTPHowlEventForwarder : public QObject
{
Q_OBJECT
public:
    KFTPHowlEventForwarder();

    KFTPHowlThread *getThread() { return &m_thread; }
private:
    KFTPHowlThread m_thread;
protected:
    void customEvent(QCustomEvent *e);
private slots:
    void slotListUpdate();
signals:
    void howlListUpdate();
};

#endif
