/*
 * This file is part of the KFTPGrabber project
 *
 * Copyright (C) 2003-2004 by the KFTPGrabber developers
 * Copyright (C) 2003-2004 Jernej Kos <kostko@jweb-network.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
 * NON-INFRINGEMENT.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA.
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */

#ifndef KFTPCONFIGURATION_H
#define KFTPCONFIGURATION_H

#include "kftpfileexistsactions.h"

#include <qcolor.h>
#include <qfont.h>
#include <qobject.h>
#include <qpoint.h>
#include <qsize.h>
#include <qstringlist.h>

typedef struct {
    QString pattern;
    QColor color;
} PatternStruct;

class KFTPFileViewColorizer : public QObject
{
friend class KFTPConfiguration;
public:
    KFTPFileViewColorizer(QObject *parent = 0);

    void addFilePattern(const QString &pattern, const QColor &color);
    QColor getColor(const QString &name);
private:
    QValueList<PatternStruct> m_filePatterns;
};

extern KFTPFileViewColorizer *FTPFileColorizer;

/**
@author Jernej Kos
*/
class KFTPConfiguration : public QObject {
Q_OBJECT
public:
    void read();
    void write();
    void emitChange();

    void loadToColorizer();
    char ftpMode(const QString &filename);
    bool isOnSkipList(const QString &filename);
    QString getGlobalMail();
    
    KFTPQueue::FileExistsActions m_fileExistsDownActions;
    KFTPQueue::FileExistsActions m_fileExistsUpActions;
    
    char m_transMode;

    QStringList m_filterList;
    bool m_enableHighlight;

    bool m_globalMail;
    QString m_anonMail;

    int m_retryCount;
    int m_retryTime;
    QString m_defLocalDir;
    QString m_defRemoteDir;

    bool m_useCache;
    QStringList m_asciiList;
    
    bool m_encryptBookmarks;

    bool m_enableSkipList;
    bool m_skipEmptyFiles;
    bool m_skipEmptyDirs;
    bool m_applySkipToDirs;
    bool m_skipNoQueue;
    QStringList m_skipList;

    bool m_showBalloons;
    bool m_showBalloonWhenQueueEmpty;
    bool m_showRetrySuccessBalloon;
    bool m_confirmExit;
    bool m_startMinimized;
    bool m_showSplash;
    
    bool m_diskCheckSpace;
    int m_diskCheckInterval;
    int m_diskMinFreeSpace;

    QFont m_logFont;
    QColor m_logCommandsColor;
    QColor m_logResponsesColor;
    QColor m_logMultilineColor;
    QColor m_logErrorColor;
    QColor m_logStatusColor;
    bool m_logSaveToFile;
    QString m_logOutputFilename;

    bool m_overwriteFiles;
    bool m_portForceIp;
    QString m_portIp;
    bool m_queueOnDND;
    bool m_lowercaseDownload;
    
    bool m_showTree;
    bool m_showHiddenFiles;
    bool m_showSizeInBytes;
    
    QSize m_size;
    QPoint m_position;
private:
    KFTPConfiguration();
    KFTPConfiguration(const KFTPConfiguration&);

    friend KFTPConfiguration &FTPConfig();
signals:
    void configChanged();
};

// global function for settings access
KFTPConfiguration &FTPConfig();

#endif
