/*
 * This file is part of the KFTPGrabber project
 *
 * Copyright (C) 2004 by the KFTPGrabber developers
 * Copyright (C) 2004 Jernej Kos <kostko@jweb-network.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
 * NON-INFRINGEMENT.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA.
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */

#include "classwrappers.h"

namespace KFTPGrabberScript {

Wrappers::Wrappers()
{
  registerWrapper("KFTPQueue::Transfer");
  registerWrapper("KFTPSession");
  registerWrapper("KFTPClientThr");
}

QObject *Wrappers::create(const QString &className, void *ptr)
{
  qDebug("Wrapper factory called.");
  
  if (className == "KFTPQueue::Transfer")
    return new FtpTransfer((KFTPQueue::Transfer*) ptr);
  else if (className == "KFTPSession")
    return new FtpSession((KFTPSession*) ptr);
  else if (className == "KFTPClientThr")
    return new FtpClient((KFTPClientThr*) ptr);
  
  return 0L;
}

//////////////////////////////////////////////////////////////////////////////

void FtpTransfer::execute()
{
  if (m_transfer)
    m_transfer->delayedExecute();
}

void FtpTransfer::stop()
{
  if (m_transfer)
    m_transfer->abort();
}

void FtpTransfer::setSourcePath(QString path)
{
  if (m_transfer) {
    KURL sourceUrl = m_transfer->getSourceUrl();
    sourceUrl.setPath(path);
    m_transfer->setSourceUrl(sourceUrl);
  }
}

void FtpTransfer::setDestPath(QString path)
{
  if (m_transfer) {
    KURL destUrl = m_transfer->getDestUrl();
    destUrl.setPath(path);
    m_transfer->setDestUrl(destUrl);
  }
}

QString FtpTransfer::getSourcePath() const
{
  if (m_transfer)
    return m_transfer->getSourceUrl().path();
    
  return QString::null;
}

QString FtpTransfer::getDestPath() const
{
  if (m_transfer)
    return m_transfer->getDestUrl().path();
    
  return QString::null;
}

//////////////////////////////////////////////////////////////////////////////

bool FtpSession::isRemote() const
{
  if (m_session)
    return m_session->isRemote();
    
  return false;
}

bool FtpSession::isLocked() const
{
  if (m_session)
    return !m_session->canLock();
    
  return false;
}

KFTPClientThr *FtpSession::getClient()
{
  if (m_session)
    return m_session->getClient();
    
  return 0L;
}

void FtpSession::abort()
{
  if (m_session)
    m_session->abort();
}

void FtpSession::close()
{
  if (m_session)
    FTPSessionManager->slotSessionCloseRequest(m_session->getFileView());
}

//////////////////////////////////////////////////////////////////////////////

void FtpClient::sendComand(const QString &cmd)
{
  if (m_client)
    m_client->rawCommand(cmd);
}

QString FtpClient::lastReply()
{
  if (m_client)
    m_client->getClient()->getRespBuffer();

  return QString::null;
}

};
#include "classwrappers.moc"
