/*
 * This file is part of the KFTPGrabber project
 *
 * Copyright (C) 2004 by the KFTPGrabber developers
 * Copyright (C) 2004 Jernej Kos <kostko@jweb-network.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
 * NON-INFRINGEMENT.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA.
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */

#include <config.h>

#ifdef HAVE_QSA
 
#ifndef KFTPGRABBERSCRIPTCLASSWRAPPERS_H
#define KFTPGRABBERSCRIPTCLASSWRAPPERS_H

#include <qswrapperfactory.h>
#include <qguardedptr.h>
#include <qobject.h>

#include "kftpsession.h"
#include "kftpqueue.h"

namespace KFTPGrabberScript {

class Wrappers : public QSWrapperFactory
{
public:
    Wrappers();
    QObject *create(const QString &className, void *ptr);
};

/**
This class is for use in QSA scripts only. It is a wrapper class for KFTPQueueTransfer.

@author Jernej Kos
*/
class FtpTransfer : public QObject
{
Q_OBJECT
Q_PROPERTY(QString sourcePath READ getSourcePath WRITE setSourcePath)
Q_PROPERTY(QString destPath READ getDestPath WRITE setDestPath)
public:
    FtpTransfer(KFTPQueue::Transfer *transfer) : m_transfer(transfer) {};
    
    void setSourcePath(QString path);
    void setDestPath(QString path);
    QString getSourcePath() const;
    QString getDestPath() const;
private:
    QGuardedPtr<KFTPQueue::Transfer> m_transfer;
public slots:
    void execute();
    void stop();
};

/**
This class is for use in QSA scripts only. It is a wrapper class for KFTPSession.

@author Jernej Kos
*/
class FtpSession : public QObject
{
Q_OBJECT
Q_PROPERTY(bool remote READ isRemote)
Q_PROPERTY(bool locked READ isLocked)
public:
    FtpSession(KFTPSession *session) : m_session(session) {};
    
    bool isRemote() const;
    bool isLocked() const;
public slots:
    KFTPClientThr *getClient();
    
    void abort();
    void close();
private:
    QGuardedPtr<KFTPSession> m_session;
};

/**
This class is for use in QSA scripts only. It is a wrapper class for KFTPClientThr.

@author Jernej Kos
*/
class FtpClient : public QObject
{
Q_OBJECT
public:
    FtpClient(KFTPClientThr *client) : m_client(client) {};
public slots:
    void sendComand(const QString &cmd);
    QString lastReply();
private:
    QGuardedPtr<KFTPClientThr> m_client;
};

};

#endif

#endif
