/*
 * This file is part of the KFTPGrabber project
 *
 * Copyright (C) 2004 by the KFTPGrabber developers
 * Copyright (C) 2004 Jernej Kos <kostko@jweb-network.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
 * NON-INFRINGEMENT.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA.
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */

#include <config.h>

#ifdef HAVE_QSA

#ifndef KFTPSCRIPTING_H
#define KFTPSCRIPTING_H

#include <qobject.h>
#include <qsproject.h>

class KFTPScriptEditor;

/**
This class provides advanced application scripting using QSA (Qt Script for Applications).

@author Jernej Kos
*/
class KFTPScripting : public QObject
{
Q_OBJECT
friend class KFTPScriptEditor;
public:
    KFTPScripting(QObject *parent = 0, const char *name = 0);
    ~KFTPScripting();
    
    /**
     * Shows a script editor dialog, so use can edit script connection with
     * program events.
     */
    void showScriptEditor();
    
    /**
     * Saves the current project to the datafile.
     */
    void saveToFile();
    
    /**
     * Loads the current project from the datafile.
     */
    void loadFromFile();
    
    static KFTPScripting *getInstance();
private:
    KFTPScriptEditor *m_scriptEditor;
    QSProject *m_project;
    
    /**
     * Adds all KFTPGrabber interfaces for use in scripts.
     */
    void addInterfaces();
    
    /**
     * Connect all qsa* signals to appropriate slots in this class.
     */
    void connectQsaSignals();
    
    static KFTPScripting *m_instance;
private slots:
    void qsaAppStartup();
    void qsaAppExit();
    
    void qsaTransferComplete(long);
    void qsaTransferStart(long);
    void qsaTransferAbort(long);
};

#endif

#endif


