/*
 * This file is part of the KFTPGrabber project
 *
 * Copyright (C) 2003-2004 by the KFTPGrabber developers
 * Copyright (C) 2003-2004 Jernej Kos <kostko@jweb-network.net>
 * Copyright (C) 2004 Markus Brueffer <markus@brueffer.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
 * NON-INFRINGEMENT.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA.
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */

#ifndef KFTPQUICKCONNECTDIALOG_H
#define KFTPQUICKCONNECTDIALOG_H

#include "kftpquickconnectlayout.h"

#include <kdialogbase.h>
#include <kurl.h>

class KFTPBookmarkEditorTLS;

/**
@author Jernej Kos
*/
class KFTPQuickConnectDialog : public KDialogBase
{
Q_OBJECT
public:
    KFTPQuickConnectDialog(QWidget *parent = 0, const char *name = 0);
    ~KFTPQuickConnectDialog();
    
    KURL getServerURL();
    
    int     getFTPMode();
    QChar   getTLSMode();
    bool    isCertChecked();
    QString getCertPath();

    void setHost(QString &host);
    void setPort(int port);
    void setFocusToUser();
        
private:
    enum ServerProtocol {
      SP_FTP = 0,
      SP_SSL_EXPLICIT,
      SP_SSL_IMPLICIT,
      SP_SFTP
    };
    
    KFTPQuickConnectLayout *m_layout;

    bool m_noUrlChange;
    KURL m_curUrl;
    KFTPBookmarkEditorTLS *m_protocolAdvancedDialog;
private slots:
    virtual void slotOk();

    void slotUrlChanged(const QString &);
    void slotHostChanged(const QString&);
    void slotPortChanged(int);
    void slotUserChanged();
    void slotPassChanged();
    void slotAnonClicked();
    void slotProtocolChanged(int);
    void slotProtoAdvancedClicked();
};

#endif
