/*
 * This file is part of the KFTPGrabber project
 *
 * Copyright (C) 2003-2004 by the KFTPGrabber developers
 * Copyright (C) 2003-2004 Jernej Kos <kostko@jweb-network.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
 * NON-INFRINGEMENT.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA.
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */

#include "kftpserverlineedit.h"
#include "kftpselectserverdialog.h"

#include <kdialog.h>
#include <klineedit.h>
#include <kpushbutton.h>
#include <klocale.h>

#include <qlayout.h>

KFTPServerLineEdit::KFTPServerLineEdit(QWidget *parent, const char *name, WFlags f)
 : QWidget(parent, name, f)
{
  QHBoxLayout *layout = new QHBoxLayout(this, 0, KDialog::spacingHint());
  KLineEdit *serverName = new KLineEdit(this, "server name");
  serverName->setReadOnly(true);

  KPushButton *selectButton = new KPushButton(i18n("Select..."), this);
  selectButton->setFlat(true);
  connect(selectButton, SIGNAL(clicked()), this, SLOT(selectButtonClicked()));

  layout->addWidget(serverName);
  layout->addWidget(selectButton);
}

KFTPServerLineEdit::~KFTPServerLineEdit()
{
}

void KFTPServerLineEdit::clear()
{
  KLineEdit *serverName = static_cast<KLineEdit*>(child("server name"));
	serverName->clear();
}

void KFTPServerLineEdit::setCurrentServer(QDomNode server)
{
  KLineEdit *serverName = static_cast<KLineEdit*>(child("server name"));
  currentServer = server;
  serverName->setText(currentServer.toElement().attribute("name", "No name"));

  emit serverChanged(currentServer);
}

void KFTPServerLineEdit::selectButtonClicked()
{
  KFTPSelectServerDialog *sDialog = new KFTPSelectServerDialog(this);
  if (sDialog->exec() == QDialog::Accepted)
    setCurrentServer(sDialog->getSelectedServer());
}


