/*
 * This file is part of the KFTPGrabber project
 *
 * Copyright (C) 2003-2004 by the KFTPGrabber developers
 * Copyright (C) 2003-2004 Jernej Kos <kostko@jweb-network.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
 * NON-INFRINGEMENT.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA.
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */

#include "kftpzeroconflistview.h"
#include "kftpapi.h"
#include "kftpsession.h"

#include <klocale.h>
#include <kiconloader.h>

KFTPZeroConfListView::KFTPZeroConfListView(QWidget *parent, const char *name)
 : KFTPListView(parent, name)
{
  // Set some stuff
  setMinimumWidth(150);
  setFullWidth(true);
  addColumn(i18n("Sites near you"));
  setRootIsDecorated(true);
  setEmptyListText(i18n("No sites published."));
  setItemsRenameable(false);
  
#ifdef HAVE_HOWL
  connect(KFTPAPI::getInstance()->howlEvents(), SIGNAL(howlListUpdate()), this, SLOT(slotSitesChanged()));
  connect(this, SIGNAL(executed(QListViewItem*)), this, SLOT(slotSiteExecuted(QListViewItem*)));
  
  slotSitesChanged();
#endif
}

void KFTPZeroConfListView::slotSitesChanged()
{
#ifdef HAVE_HOWL
  // Update the site list
  QValueList<KFTPHowlService>::iterator i;
  QValueList<KFTPHowlService> list = KFTPAPI::getInstance()->howlInterface()->getServiceList();
  
  clear();
  if (list.size() > 0) {
    for (i = list.begin(); i != list.end(); ++i) {
      QString name = (*i).getServiceName();
      QString ip = (*i).getServiceIp();
      QString port = QString::number((*i).getServicePort());
      
      KListViewItem *site = new KListViewItem(this, name, ip, port);
      site->setPixmap(0, SmallIcon("lan"));
    }
  }
#endif
}

void KFTPZeroConfListView::slotSiteExecuted(QListViewItem *item)
{
#ifdef HAVE_HOWL
  // Connect to the site
  KFTPAPI::getInstance()->mainWindow()->slotQuickConnect(item->text(0), item->text(1), item->text(2).toInt());
#endif
}

#include "kftpzeroconflistview.moc"
