/*
 * This file is part of the KFTPGrabber project
 *
 * Copyright (C) 2003-2004 by the KFTPGrabber developers
 * Copyright (C) 2003-2004 Jernej Kos <kostko@jweb-network.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
 * NON-INFRINGEMENT.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA.
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */

#ifndef KFTPQUEUEVIEW_H
#define KFTPQUEUEVIEW_H

#include <qguardedptr.h>
#include <kaction.h>

#include "kftplistview.h"
#include "kftpqueue.h"

class KFTPQueueViewItem : public QObject, public QListViewItem
{
Q_OBJECT
public:
    KFTPQueueViewItem(KFTPQueue::Transfer *transfer, QListView *parent);
    KFTPQueueViewItem(KFTPQueue::Transfer *transfer, QListViewItem *parent);

    void setTransfer(KFTPQueue::Transfer *transfer);
    KFTPQueue::Transfer *getTransfer();

    int compare(QListViewItem *i, int col, bool) const;
    void refresh();
    virtual void paintCell(QPainter *p, const QColorGroup &cg, int column, int width, int alignment);
private:
    QGuardedPtr<KFTPQueue::Transfer> m_queueTransfer;
private slots:
    void slotUpdateItemRequested();
};

/**
@author Jernej Kos
*/
class KFTPQueueView : public KFTPListView
{
friend class KFTPQueueViewToolbar;
Q_OBJECT
public:
    KFTPQueueView(QWidget *parent = 0, const char *name = 0);

    ~KFTPQueueView();

    void setEnableContext(bool value);
    
    void initActions();
    void updateActions(KFTPQueueViewItem *item);
private:
    bool m_enableContext;
    
    // Actions
    KAction *m_launchAction;
    KAction *m_abortAction;
    KAction *m_removeAction;
    KAction *m_removeAllAction;
    KAction *m_moveUpAction;
    KAction *m_moveDownAction;
    KAction *m_editAction;
    
    // Currently selected transfer
    KFTPQueueViewItem *m_curSelection;
    
    KActionCollection *actionCollection();
private slots:
    void slotQueueUpdate();
    void slotTransferRemoved(long id);
    void slotTransferAdded(KFTPQueue::Transfer *transfer);
    void contextMenuRequested(KListView* l, QListViewItem* i, const QPoint& p);
    
    // Slots for actions
    void slotLaunch();
    void slotAbort();
    void slotRemove();
    void slotRemoveAll();
    void slotMoveUp();
    void slotMoveDown();
    void slotEdit();
};

#endif
