/*
 * This file is part of the KFTPGrabber project
 *
 * Copyright (C) 2004 by the KFTPGrabber developers
 * Copyright (C) 2004 Jernej Kos <kostko@jweb-network.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
 * NON-INFRINGEMENT.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA.
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */

#include "kftpqueueviewtoolbar.h"
#include "kftpapi.h"
#include "kftpqueue.h"
#include "kftpqueueconverter.h"
#include "kftpsearchdialog.h"

#include <klocale.h>
#include <kmessagebox.h>
#include <kfiledialog.h>

KFTPQueueViewToolbar::KFTPQueueViewToolbar(QWidget *parent,KFTPQueueView *view)
 : KToolBar(parent, "queue view toolbar", false, false)
{
  // Set the QueueView
  m_queueView = view;
  
  connect(m_queueView, SIGNAL(selectionChanged()), this, SLOT(updateActions()));
  connect(FTPQueueManager, SIGNAL(queueUpdate()), this, SLOT(updateActions()));
  
  // Icons should be 16x16
  setIconSize(16);
  
  setMovingEnabled(false);

  initActions();
  updateActions();
  initToolbar();
}

KActionCollection *KFTPQueueViewToolbar::actionCollection()
{
  return KFTPAPI::getInstance()->mainWindow()->actionCollection();
}

void KFTPQueueViewToolbar::initToolbar()
{
  m_loadAction->plug(this);
  m_saveAction->plug(this);
  insertSeparator();
  m_startAction->plug(this);
  m_pauseAction->plug(this);
  m_stopAction->plug(this);
  insertSeparator();
  m_queueView->m_removeAction->plug(this);
  m_addAction->plug(this);
  m_searchAction->plug(this);
}

void KFTPQueueViewToolbar::initActions()
{
  // Init the actions
  m_loadAction = new KAction(i18n("&Load queue from file"), "fileopen", KShortcut(), this, SLOT(slotLoad()), actionCollection(), "load");
  m_saveAction = new KAction(i18n("&Save queue to file"), "filesaveas", KShortcut(), this, SLOT(slotSave()), actionCollection(), "save");
  
  m_startAction = new KAction(i18n("S&tart"), "player_play", KShortcut(), this, SLOT(slotStart()), actionCollection(), "start");
  m_pauseAction = new KAction(i18n("&Pause"), "player_pause", KShortcut(), this, SLOT(slotPause()), actionCollection(), "pause");
  m_stopAction = new KAction(i18n("St&op"), "player_stop", KShortcut(), this, SLOT(slotStop()), actionCollection(), "stop");
  
  m_addAction = new KAction(i18n("&Add transfer..."), "filenew", KShortcut(), this, SLOT(slotAdd()), actionCollection(), "add");
  m_searchAction = new KAction(i18n("&Search and replace..."), "find", KShortcut(), this, SLOT(slotSearch()), actionCollection(), "search");
}

void KFTPQueueViewToolbar::updateActions()
{
  m_loadAction->setEnabled(true);
  m_saveAction->setEnabled(true);
  
  m_startAction->setEnabled(!FTPQueueManager->queueProcRunning() && FTPQueueManager->getQueueTransferList()->count() > 0 && FTPQueueManager->getNumRunning() == 0);
  m_pauseAction->setEnabled(false);
  m_stopAction->setEnabled(FTPQueueManager->queueProcRunning());
  
  m_addAction->setEnabled(true);
  m_searchAction->setEnabled(true);
  
  m_queueView->updateActions(static_cast<KFTPQueueViewItem*>(m_queueView->selectedItem()));
}

void KFTPQueueViewToolbar::slotSearch()
{
  KFTPSearchDialog *dialog = new KFTPSearchDialog();
  
  dialog->exec();
  delete dialog;
}

void KFTPQueueViewToolbar::slotLoad()
{
  if (KMessageBox::warningContinueCancel(0L, i18n("Loading a new queue will overwrite the existing one! Are you sure you want to continue ?"), i18n("Load queue")) == KMessageBox::Cancel)
    return;

  QString loadPath = KFileDialog::getOpenFileName();
  
  if (!loadPath.isEmpty()) {
    FTPQueueManager->getConverter()->importQueue(loadPath);
  }
}

void KFTPQueueViewToolbar::slotSave()
{
  QString savePath = KFileDialog::getSaveFileName();
  
  if (!savePath.isEmpty()) {
    FTPQueueManager->getConverter()->exportQueue(savePath);
  }
}

void KFTPQueueViewToolbar::slotStart()
{
  // Begin queue processing
  FTPQueueManager->startQueueTransfer();
}

void KFTPQueueViewToolbar::slotPause()
{
}

void KFTPQueueViewToolbar::slotStop()
{
  // Abort queue processing
  FTPQueueManager->abortQueueTransfer();
}

void KFTPQueueViewToolbar::slotAdd()
{
}

#include "kftpqueueviewtoolbar.moc"
